// Fill out your copyright notice in the Description page of Project Settings.


#include "MovingSphereActor.h"

// Sets default values
AMovingSphereActor::AMovingSphereActor()
{
 	// Set this actor to call Tick() every frame.  You can turn this off to improve performance if you don't need it.
	PrimaryActorTick.bCanEverTick = true;

	//Create Mesh Component and set as root
	UStaticMeshComponent* meshComponent = CreateDefaultSubobject<UStaticMeshComponent>(TEXT("Mesh Component"));
	RootComponent = meshComponent;		// or you can use: SetRootComponent(meshComponent);

	// Create Static Mesh Sphere
	UStaticMesh* mesh = ConstructorHelpers::FObjectFinder<UStaticMesh>(TEXT("StaticMesh'/Engine/BasicShapes/Sphere.Sphere'")).Object;
	meshComponent->SetStaticMesh(mesh);

	// Find and set material 
	Material = ConstructorHelpers::FObjectFinder<UMaterial>(TEXT("Material'/Engine/ArtTools/RenderToTexture/Materials/M_DebugSphereBounds_01.M_DebugSphereBounds_01'")).Object;
	meshComponent->SetMaterial(0, Material);
}

float AMovingSphereActor::ComputeSin()
{
	// f(t) = A*sin(2 * Pi * f * t + phi).
	float SinValue = Amplitude * FMath::Sin(2 * PI * Frequency * CurrentTime + phase);
	return SinValue;
}

// Called when the game starts or when spawned
void AMovingSphereActor::BeginPlay()
{
	Super::BeginPlay();

	// get original location
	origin = GetActorLocation();	
}

// Called every frame
void AMovingSphereActor::Tick(float DeltaTime)
{
	Super::Tick(DeltaTime);

	if (AnimateMesh)
	{
		CurrentTime += DeltaTime;

		float sin = ComputeSin();

		FVector updatedLocation = origin;
		updatedLocation.Z += sin;

		SetActorLocation(updatedLocation);
	}
}

